
# q-expansion of newform 1100.6.a.i, downloaded from the LMFDB on 22 December 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1100
weight = 6
poly_data = [132029745, 54177943, -28296355, -476334, 365994, 1122, -1155, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[-21300299853527505, 5146516356211948, 387790186642087, -31986258412711, -1193739185525, 55968546197, 972671008, -29993519], 25734183149700], [[-4051220991511035, -88966529750684, -102661264343971, -12595175738537, 773761442225, 45229096399, -921476764, -37037373], 25734183149700], [[-1711826607304095, 615307221226622, -53889707313957, -7520004964929, 274101152025, 23951024733, -265098288, -21022391], 12867091574850], [[2006762857827555, 615307221226622, -66756798888807, -7520004964929, 274101152025, 23951024733, -265098288, -21022391], 12867091574850], [[-482867449744815, -811036806695936, 33653466043191, 11023209429977, -121794895375, -33424966629, 99527944, 27803583], 4289030524950], [[-1227490571860215, 1414271950987559, 1721727809671, -24316557248913, 28968909500, 83784812576, -27532536, -75377227], 2144515262475]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0], [-1, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0], [-22, -2, 0, 0, 0, 1, 0, 0], [-121, 0, 0, 0, 0, 0, 0, 0], [134, 6, -1, 0, 0, -1, 0, 0], [-2, -21, 1, 1, -2, 2, 1, 1], [-173, 20, 1, -1, -1, 0, -2, 0], [-156, -61, -1, 0, -8, 2, 2, -1], [-1476, 12, 3, 6, -9, 13, 5, -2], [454, -52, 2, -7, 7, -19, 6, 0], [1007, 77, 0, 12, -13, 18, -7, -6], [1979, 181, 0, 8, 14, -55, 6, 4], [86, -79, 4, 0, -33, -20, -13, 4], [1103, 307, -7, -19, 1, 15, -26, 2], [3143, -40, 1, -7, -6, -58, -22, 3], [90, 713, -12, 18, 28, 32, 36, -17], [-6784, 74, -3, 9, 22, -21, 68, 8], [-13704, 210, -11, -23, 15, 111, 51, 10], [-5723, 623, 8, -53, -9, 1, -25, 2], [309, -308, -12, 64, 65, 6, 12, -45], [9006, 2187, -14, -20, 127, -30, 3, -1], [-627, -456, 16, -54, 118, -150, -59, 36], [13061, 1742, 19, -19, -38, -16, 17, -20], [-9434, 981, 50, -22, 158, -291, 117, 46], [-5643, 2621, -46, 81, 44, 67, -54, 38], [-18906, -584, -5, 166, 84, 170, -28, -52], [-23494, 1460, -5, -157, 9, 14, 53, -57], [-16607, 2578, 133, -64, -61, 285, 150, 43], [17858, -2673, -37, -49, 166, 47, -11, -13], [-16256, 5809, -94, 128, -239, -50, -165, -33], [-21488, 1177, 42, -224, 375, 497, -107, 96], [-1656, 4094, 32, -90, 301, -601, -169, -103], [23336, 6854, 37, 69, -13, 264, -219, 59], [87785, 5906, -168, -280, -450, -256, -161, -71], [-59561, -4333, 179, -31, -392, 262, 1, 230], [-61455, 1064, -215, 319, 175, -685, 252, 95], [-108923, -6426, -12, -346, 246, -74, 228, -73], [-149146, 6065, -252, -94, -71, 945, -273, 93], [28275, -1548, 23, 354, 306, -571, 153, 177], [136795, -2640, -524, -278, 540, 378, 426, -77], [-94994, 8626, 335, 443, -136, -1900, -49, -166], [-227970, -6848, -370, -231, 409, 503, 187, -300], [-128011, 12328, 414, -360, -242, 156, -947, -69], [-294548, 323, 251, -86, 901, -270, 108, -103], [86780, -13330, 813, -150, -792, 48, -28, 208], [-181005, -20493, 80, 472, -315, -1139, 726, 250], [-274668, -7821, 178, -254, 1098, -686, 1136, -259], [-310864, 2048, 271, 293, 649, 379, -477, -267], [251385, -9195, 1064, -242, 1540, -3793, -343, -12], [-178655, 13034, 830, 556, -1113, 890, 340, 69], [539326, -12978, -177, 127, 1613, -1096, -885, 12], [-281766, -2305, 582, 544, 1235, 1141, -66, -285], [-461828, -20109, -253, 733, -2989, 3527, -1210, -437], [-276694, -25369, 21, 503, -1074, -4085, -610, 432], [49875, 5863, -809, -849, -2114, 54, -1531, 452], [427919, -33779, 907, 161, 947, -1420, -116, -252], [-391168, -28651, 43, -1689, 1852, 242, -134, 45], [-626770, -38453, -1335, -543, -325, -2748, 1096, -155], [-354000, 1055, -666, 12, 2158, -1739, 1291, -543], [-211360, -7741, 480, 1116, 4167, 1336, 535, 299], [-459933, 10688, 166, -1158, 2194, 4578, 2055, -527], [-644193, -8847, 597, -1763, -2458, -10225, -177, 414], [-611013, -23978, -1448, 1347, 2107, -3327, 887, -247], [-635826, 34238, 162, -86, -34, 2122, 1368, -138], [-647105, -4827, 246, 976, 2386, -3645, -1801, -48], [-276460, -28609, 1130, 240, 5078, -7308, 100, -245], [-1282048, -22836, -41, 843, -3927, -3713, 327, 696], [-992630, 54554, -887, 529, 2639, 1190, 771, 678], [653167, -8990, 569, -1282, 3830, -1923, 4387, 663], [-367983, 12, -412, -612, -10668, 252, -574, -146], [859232, 7178, 573, 1667, -5659, 4341, -2181, -1070], [-1321515, 79069, 371, -572, 5642, -10224, -139, -356], [-798003, 7011, -2018, 502, -5316, 16627, -1690, 218], [593707, -11409, 2188, 1190, -164, -13860, -1027, 40], [-62146, -28345, -546, 1673, 12749, -16617, 3078, 1333], [813733, 17232, 2080, 1942, 3040, 10306, -169, 735], [-1018364, 29151, 1286, -3154, -876, 1337, -6818, 1183], [-1218082, 48687, 950, -1162, -3693, -13388, 1037, 1296], [719865, -18453, -2065, -2915, -5599, -906, 2641, 332], [95654, 6285, 3077, -4099, -2391, -507, 2595, 2105], [-256094, 51978, -127, 527, -9654, -17214, 501, -346], [131028, -34997, 239, 981, 610, -20684, -3106, -2221], [-371002, -14490, 1831, -177, -3061, 8755, -912, 983], [429664, 49525, 277, 3215, -4728, -713, 260, -3399], [-263527, -71574, 1945, -3223, 9559, -15269, -4940, -1507], [629626, 44931, -831, 5683, 2873, 13104, 5834, -878], [-545745, 82234, -267, 5029, -2056, 14377, -1669, -1067], [-1138985, 47325, -98, -3986, 12050, 20711, 52, 2186], [-968742, -91106, -1903, 1732, -5678, -7672, -2487, -2146], [355571, 84789, -1551, 29, 5453, 131, -7180, 2786], [-274569, 36245, -125, -3561, 1358, -8936, 7061, 3828], [-1374710, 184674, 2677, -2434, -612, 2822, -4179, -1594], [214139, -96638, -494, -778, 4046, 6387, 699, 754], [-244955, 92210, -983, 713, -1517, -3115, -4765, 733], [-1141879, -103878, 2058, -3616, 14492, -7580, -7191, -761], [-137388, 203724, 2915, -867, -3002, 14706, -2527, 98], [-386657, -12189, 2341, 7261, 4256, 32989, -1429, 3319], [-975203, -234825, -4064, -4450, -8315, 13286, -5490, 1605], [-1003698, 61391, -970, 6001, 12820, -5827, 505, -461], [581748, 254339, 1087, 1327, -258, -34488, 9608, 1844], [-259009, 100876, 1954, 2069, 1031, 9120, 2958, -3743], [-1396791, 22564, -6384, 3948, -14214, 15261, -2075, -1963], [1372330, 257728, 411, 1525, -8170, 17397, -9996, -1644], [1161728, -222549, -4944, -2466, 2937, 59707, -5215, -2366], [-147852, -238763, -2721, -6833, 2075, 18012, 5661, -2385], [1242667, 87033, 3492, -4970, -11920, -39108, -6460, -1670], [574880, 88785, 2072, 9812, -24702, 56053, -15091, -5529], [-723811, -458077, -2705, 7241, -9069, -15533, -5247, -1480], [-1041319, 53090, 2928, 3774, -6149, 7472, -4902, 3991], [-2503990, -159108, 13039, 3903, -5067, 28021, -993, -174], [2421779, -57043, -8691, 9843, 9352, 42, 3776, -3376], [1700423, -96931, -3551, 5201, -1038, 30017, 6125, -2241], [-1507820, 48765, 7247, -9127, 11723, -10855, -419, 1035], [3797351, -385192, -5062, -186, -15660, 15308, -5260, 2425], [-1235896, -174544, 8067, -1009, 22247, -6635, 24014, -1747], [-544586, 262106, 504, -8848, 2322, -6734, -7132, -5316], [610918, -30933, -3453, 13465, -20293, 20601, 497, -461], [2637047, 89281, 5097, -11977, 15385, 22018, 3484, -280], [-3734396, -56940, -10359, -11165, 18081, 17161, -8183, 1587], [2764588, -72633, -11105, -16729, 11368, -50125, 1269, 1227], [2115864, 171137, -7890, -9962, 7510, 11141, 13499, -255], [6181592, 161195, -1868, -12253, 27885, 10089, 6916, -2405], [-413974, -65795, 10598, 1178, -272, -35854, -5578, 1861], [3822662, -249146, -12137, 10017, 6949, 19373, 14436, -926], [2126964, -79063, -2733, 9876, -41080, 9202, -8315, -2375], [-3435632, -905788, -10279, -2683, -10359, -33813, 5429, -1866], [-3972743, -688319, -12430, -7124, 12830, -15102, 3491, -12374], [6563415, -220660, -12830, -13511, -19791, 25629, -6724, 4223], [3712677, -138782, 9702, -2489, 14021, -21194, 134, -6143], [-5018234, -616402, 8166, -2104, 32692, -11377, -5690, 3002], [-2727393, -110920, 6409, 1629, 29103, -19348, 28720, -1969], [3387604, -142612, 3097, -4918, -45610, -13110, -9230, 54], [6767289, 61279, -8137, 2875, 19034, 26035, -4796, 7868], [3704506, -518076, 1821, -7937, 1029, -51623, -11891, 8538], [1295357, -350023, -3738, 31260, -8992, -19279, 9342, 3590], [5988538, -491636, -9701, 11869, 2590, 19926, 14587, -2930], [5628899, 185515, 16090, 14238, -28933, 5619, 1826, 2334], [12580627, -52181, -6412, 15850, -49308, -43849, -35673, -6026], [-7188452, 273454, 10705, -34817, 5663, -4039, -2911, -3800], [5262998, 169635, 25821, 8013, 39452, 60574, 4196, 5427], [-1054825, -404417, 2916, -4261, -11937, 31331, 21813, -13660], [-4801533, 215532, -8030, 5728, -60142, 47000, -26393, -6499], [4427604, -15839, -4487, -12741, 45136, -72683, -8942, 10722], [123171, -147447, -3435, 8113, 62035, -58616, -19286, 6730], [-3160634, 537030, 3956, 25618, 37832, -20996, 8871, 372], [7089892, -91355, 1731, -4105, 270, -20318, -43535, -7085], [5452752, 23185, 16151, -31833, 12647, -4964, 10658, 4719], [-13036067, 307058, 9731, 10613, -27799, 103305, -5596, -4327], [-1562469, 672872, -6329, -714, -23002, -12992, 19166, -6189], [3721139, 773703, -493, -4548, -60946, 68382, 12230, -732], [377078, -413679, -1037, 28481, -51857, 68406, -8968, -488], [-9026565, -770857, -8219, 28087, -38963, 29417, 3858, -17896], [2874802, 253619, 14926, 10348, 18529, -33193, 1893, 7433], [3315152, -547302, -5529, 4779, -14139, 25993, -6247, -6338], [11017722, 17942, -10667, 1131, 78011, -103277, 9119, -9084], [-14814565, 338388, 19227, 12375, 7441, 95763, 28368, 12997], [1080643, -926340, -8262, 10510, 28958, -42992, -7106, -10888], [-2390909, -484598, -777, 29633, -78139, 54439, 16570, -18993], [-2522577, -213213, -18318, -5082, 4054, 77609, -1400, 7548], [7910125, 793883, -17760, 9352, 38004, -101564, 41385, 2368], [12238299, -285780, -14964, 18390, -13068, 46410, -54993, -6441], [-1931915, -91301, -17950, 11432, 36363, 110710, 6294, -1804], [7242189, 603746, -17893, -13461, -19967, 55583, -17707, 4373], [9720241, 975107, 1081, 16255, -38548, -4261, -28068, -18996], [4140871, 110519, -1437, -32504, 40262, -118182, 11710, -16756], [16643793, 230691, 19160, 6340, -28722, 32212, -34032, 11416], [4817080, 929913, -18531, -19819, -63690, 48946, 18843, 5135], [703088, 2021475, -8916, -4092, -11690, 73627, -17815, 15029], [22828006, -804380, -17699, 31765, 26169, -84723, 6169, -882], [719562, 1920073, -27930, -7068, 21543, 34013, 20375, -12662], [-2506567, -854810, 10104, -20418, 10003, -24619, -8917, -3619], [6752920, 461801, 41122, -13718, 619, -120044, -7679, 8191], [9029200, -638364, -2940, -4648, 91371, -285476, 25347, 8282], [-13271275, -1801932, 8411, 16830, 16220, 121402, -34298, -8243], [-2477788, -1252235, 28968, -13132, 59639, -4734, 51503, 16622], [7804202, 658373, 17219, 29277, -61708, 225867, 4978, -13514], [-6799447, -1499843, -19359, 31781, 15944, 55411, 27862, -7104], [-16888746, -329630, 4119, -11303, 39593, -167537, 15119, 1606], [15135197, -1695973, -45972, -1881, 25847, -20709, -11881, 318], [-5917433, -537121, 20786, -53113, 14853, -129573, -32671, 15516], [-912214, -231536, -749, -39973, -24943, -110664, -30249, 18688], [5264980, 508321, 21998, 55364, -58943, -137126, -7686, -11271], [-3106842, 1508164, 36798, -11706, -30058, 125510, 18374, -996], [-7366424, 409061, -10694, -42134, 40774, -41562, -40348, 19863], [16200189, -438831, 7622, 34878, -169055, 106558, -79547, -10236], [2202667, 1382147, -7558, -2131, 27515, 163847, 11487, 7300], [-14465257, -756140, -28211, -43929, 91161, 39427, -26531, 9377], [12066926, 1019725, 32743, 2661, 65565, -54176, 23092, -5683], [-3718249, 199748, -53499, 1931, 41467, -121017, 61260, 8847], [4005317, -11262, -21099, -23841, -65354, -166684, 27043, -12918], [-22873166, -1851539, 29798, 42358, -55995, -80, 24169, -18150], [-421885, -1343501, 23091, -28419, 37925, 230935, -7218, 19016], [-9053626, -1368579, 27650, 34970, -71092, -177363, -18822, 17461], [-34862522, -300035, 37233, 17521, -145362, 163522, -70384, -2014], [18102173, 1266708, -44101, -39703, 26359, 252025, 9935, -2882], [-15275482, -731254, -46623, 39951, -41643, -4365, -76831, -23432], [-82417, -1536311, 72654, -57528, -88047, -70822, -54601, 17566], [-18930228, 732042, 5005, -225, -100150, 161681, -24790, 4620], [-15302294, 2028021, 30663, 5365, 9784, 87841, -72446, -257], [12584455, 843981, -11299, 77878, -47575, 121496, 89081, -17288], [-3244858, -1339186, 2454, -29358, -118750, 6129, 48608, -26844], [-8061571, -1965413, -12438, -44286, 11322, -217943, -40311, 11304], [9172493, -490925, -20131, 34773, -80930, 138332, 23428, 20340], [1925028, -2679608, 16263, -10335, -19201, 59097, -61271, 24262], [6707199, 334262, 52823, -5019, -30568, -112354, 38090, 12729], [5951221, 429128, -65615, -61687, 79245, -74021, -55914, -1201], [-4226778, -1173972, -32945, 63051, 4065, -234454, 8003, -13265], [33877764, -3231750, -64639, 25863, -36783, 125839, -67283, 4454], [20416177, -393284, -45376, -14854, 96904, -177578, 53976, 21153], [-19602002, 358557, -19297, -63907, 290163, -54054, 24102, 11351], [-17430941, -931859, 24680, -31178, 87987, 181144, -34973, 38952], [-28393505, 4001654, -6480, 6860, 49236, 83716, -54214, 507], [-24444007, 1504352, -44504, 28202, 83196, -123362, -51813, -23623], [27688363, -869291, -11897, 34519, 125788, -209550, -30935, 10480], [-1332362, -352885, -68056, -32704, 134441, 86240, -16011, -15986], [-44223518, 61370, 20444, 41726, 95430, -34454, 57298, -1040], [-33663999, 1233043, -54384, -9714, 28787, 78113, -16591, -34200], [-17884408, 31279, -33559, 37814, -123070, -1126, -72508, -20905], [20304733, 944852, 23601, 58675, 86554, 24512, -55006, 4473], [-7326053, -598919, 17060, 16556, 76995, 136723, 21393, 5300], [19865984, -3412303, -1892, 20196, 23441, -238497, -89919, 21125], [10373888, -1897835, 17512, -120136, -7115, 380776, 10283, -39092], [-18262472, 1773623, 3393, 11477, 191071, 24875, -20048, 40637], [-29669570, 3372611, 13934, -18584, 14167, 67313, 34495, 74839], [10675329, -876148, 19820, -89165, -201669, -56816, -125656, 30803], [19115693, 45442, 8848, 58442, 253357, -192279, 21783, -17361], [28482011, -1047759, 27694, -1855, 173667, -331339, -55551, -38890], [-11917763, 530552, 72323, 97763, -119273, -93515, 55216, -11701], [-23443603, 1036704, 56404, -51118, 46840, -324086, 23491, 15122], [-10237107, 590876, -70898, -1532, -88569, 120657, 60005, -29953], [7117571, 2129834, 26278, 83310, -43650, 225961, 5369, 40732], [-1223917, 519335, -9739, -97737, 165532, 54844, -26847, -27884], [-38435864, 1426511, -44087, -62939, -107447, -72344, -72404, 895], [-43776741, -1497013, -52487, -52763, 246473, -240923, -15491, -16654], [-44316379, -3095967, -52617, -39547, 160610, -278328, -33791, 5970], [15244110, -780295, -39771, 6067, 20728, -174659, -121938, -45346], [32950993, 257659, -66154, -63779, 117538, -285663, -37384, 33396], [5977272, 3373777, 37385, 94089, 70209, 256683, 38280, -24279], [9467470, -2981138, 89952, 24862, -272168, -75292, -1823, 28648], [-31817899, -861481, 41723, 55601, 38217, -26903, 109240, 7894], [-9413189, 1698928, 12967, 63635, 354071, -272507, 78020, 32441], [-41956825, -1151393, -69402, 104409, -130559, 199515, 28003, -20868], [30092461, 137993, 25623, 24977, -76374, 32251, -5326, 26730], [-10997396, 699284, 8893, 56227, -252149, 102391, 129727, -8048], [-4825929, -904638, 1706, -94206, 45660, 104519, 171777, 62463], [-19288879, -480981, -49614, -53667, 90563, -143641, -154778, 3166], [-46971874, -1416172, 40206, 25664, -279682, 20656, 1349, 10982], [-16595431, 5331600, 21927, -52173, -89829, -69051, -119622, 62790], [-26403976, -243276, -19135, -104845, -121665, -379759, -68285, 58030], [-71082698, -149923, 79361, 26180, -154852, 147032, -58167, 33691], [7604288, 1593505, -21623, -85315, 228417, -140658, 14622, -6745], [-16672826, -1109353, -60516, -59915, -192821, 231499, 54954, 28613], [20668105, 3438444, -2721, 50789, -68431, -355479, -6203, -36138], [18312064, -2129881, 14923, -42128, -243149, 217696, -32798, -9203], [15821087, 1670153, 89147, 40223, -277068, 291881, -162441, -43039], [30044980, 1406075, -12841, 166823, -107720, -103013, 113533, -20965], [-47835415, 3855261, -34930, 21918, -57403, 337069, -16964, -37106], [-24026094, -2993846, -74086, -78522, 11007, 100011, 32376, 3924], [-48064132, 643744, -44648, 116082, -144128, -82810, 73608, -28976], [-66208553, 3190316, -57793, 19655, -31233, 270453, -104218, -10851], [28588424, 2997767, -26879, -131353, 74732, 482413, -69402, -1016], [1430346, 4308858, -29829, -73832, 211796, -176685, 63710, -60680], [-21290438, -1770334, -1966, 50783, -512864, 491022, -135520, -13838], [-821332, 1253438, 45150, -63652, 171958, -114240, 104097, 88911], [-52452397, -44044, -122319, -38511, 134577, 385377, 116924, -18623], [-27589864, 428779, 38662, 12962, 59503, 110802, -60174, -37989], [-26765311, -540969, -84409, -83461, -148673, -26318, 178415, 16879], [-81676960, -5181224, 59940, -141186, 276208, -238577, -28500, 331], [30475785, -3352933, -49992, -51708, -399806, 285061, -11000, 11178], [-17682372, 1333206, 40865, -92969, 77395, -75457, 204515, -58026], [-43602983, 3696205, 103106, -126892, -81592, -239328, -29873, 36696], [727159, 338881, -38127, -106831, -73994, 429929, 157773, -8253], [-27526433, -1676283, -81474, -25198, -88739, 499187, 84614, -5696], [28237080, 1469265, 69951, -72269, -475796, 294620, -53853, 41063], [-58174530, -2162180, 51592, 14767, -226857, 358849, -40686, 94996], [20748659, -781608, -44712, 61946, 452162, 256344, 263035, -74511], [-3282533, 3110869, 94713, -32305, 28370, -729024, 58904, 44972], [48994074, 5214450, 45874, 23332, -127217, -70134, -100737, 69056], [23687558, 1229937, -157478, 53396, -155615, -164293, -10233, 29229], [10585375, -5390805, -19204, 121876, 313609, 88138, 149502, -8992], [26512720, -82843, 28041, -12214, -200066, 521996, -276209, -85231], [-41201504, 713140, 3666, -15068, -425164, 210545, -50858, 29792], [20331942, 692628, 100017, -194588, -91730, -101355, -209488, 54318], [4726696, 3642383, -39130, -34792, 515551, -453131, 158695, -34258], [21142690, -943497, 55744, -25235, 161963, -39195, 195246, 112569], [-685250, -409944, -64014, 115160, 46167, -283877, -1473, 13949], [-27984923, -1546943, 145547, -126878, -203397, -163550, 136159, 24126], [-1641716, -3498067, -37048, 211385, -18949, -364307, 140113, -21183], [-9457902, 781061, 86681, -15975, 422924, 472308, 125845, 26743], [-33767509, 2049121, 39202, -221146, -106247, 317758, 28931, -5966], [139275336, 3596695, 137761, 92463, -170283, 78929, -104349, 19539], [-71917, 2788528, 62181, 214001, 111269, 858651, 4952, 34553], [39459203, -1062540, -17715, 233945, -145285, 197175, 212224, -87372], [-19791877, -1844420, 100012, 259527, 16711, 263276, 254982, 53917], [50690750, -4588057, 93295, 42470, 114459, 666676, 76758, -22669], [140369226, 559536, -103877, -24788, 411240, 364342, 10145, -88], [86261886, 1384883, 64920, -7662, -183919, -144916, -128550, -47623], [6574340, -1087193, 75091, 117521, -646516, 508611, 29340, 56242], [-40673094, -4815038, -62495, -165191, -195127, 328702, -10785, 54321], [-61022672, 6364679, -55489, -159445, 38037, -242552, -250208, 74989], [154453958, -1141523, 79881, 113828, -220238, 424922, 15441, 79059], [-10212621, -1485090, -104808, 76156, -107686, -622507, -368367, 84831], [46697466, 1179133, 44333, -48813, -59081, 48413, 61435, 35133], [29374450, -1042749, -62802, 8054, 6004, 12524, 81893, -142949], [128266789, -3376547, -24760, -175504, -119813, 191460, -159485, -31126], [41171636, 349498, -76182, 190784, -340904, 1129624, -8882, -51868], [-47065978, 220866, 22802, -246300, 136245, -1201751, -102128, -41380], [-63575023, -1927180, -21749, 216032, -99000, -191132, -173163, 78305], [-54195234, 8236410, 35640, -87911, 74065, 262798, -42533, -52100], [106082213, 6611271, -33291, 149789, 45808, -580211, 143205, 49056], [-62666059, -261153, 48549, 283577, -94901, 245350, -70470, 43410], [-93341419, 3553940, 47104, 447428, 242945, -94438, 14108, -59905], [-1685565, 576243, -54910, 73960, -237478, 564534, -382493, -126166], [57105514, -5244797, 83785, -74699, -20788, 31930, -58680, 29829], [-53507152, -3236368, -45663, -77547, -446341, 273769, -161459, -107450], [26801137, -1312546, -30466, -210656, 440884, -1047254, 376871, 33465], [-11860434, 3048134, -144593, -96477, -68475, 1015993, -72847, 48364], [-29845718, 2698184, 71804, -19744, -437324, -548650, 3984, 11472], [-78290842, -4092096, -78698, 82184, -164543, 633564, -173653, -65324], [98023337, -509658, -70468, 188880, 227238, -272369, -97559, -54217], [-4406337, -6096437, -15503, 134149, 273365, -13636, -316693, -76145], [-43801122, -1962489, -212486, -43812, -385202, 72539, 134117, -20767], [-113859147, 2684072, -6405, 161344, -142400, 579446, 48032, -98475], [48812750, 12344015, 85798, -151162, -471763, 43923, -259364, 22269], [86755787, 1777753, 141734, 37452, 170417, -756858, 390570, -19525], [-116101408, 649993, -113190, -54264, 19576, -270188, 158139, -10523], [-104008218, 4092542, 206167, 168661, -146483, 378665, 332520, 46634], [-4192252, -7453402, 157458, 36818, 244822, 150870, 31476, 127854], [14167691, -62265, 68530, -211981, 250805, -866529, 211967, -52420], [47514865, -3532037, 140342, -204763, 313895, 570635, 9245, -17566], [245759473, -7860579, 72191, -151445, -393380, 169543, -37920, 15530], [-140181642, -4416157, 18460, 237646, 177951, -655368, 28457, 57143], [108366368, 3909398, -106594, -392008, 117890, -277703, -223874, 19125], [5774220, 274877, 288077, 118303, 157014, 486349, 209552, 97712], [163720428, -5886036, 68094, -163152, -324166, -179350, 73708, -25772], [-114588222, -5958190, -83498, -124472, -336512, -405430, -32814, -27070], [7161075, -1686286, -243695, 73461, -60363, 114513, 325350, 52509], [179912810, 812210, -143068, -47832, -62947, 883065, -63560, -182], [-39417559, -9874592, -38826, 15462, 17662, -882341, -234657, 77809], [-71765432, 7111896, 48855, 233819, 135441, -428567, 205893, -3958], [-48218938, 2890736, -183808, -296986, 812076, -190966, -182937, 75107], [12259807, -996139, -12949, 131833, 893935, 226276, 239837, -53766], [125547971, 2981513, 28020, 85095, -614981, 457631, -26214, -54938], [123912318, -2000389, 20842, 54972, 531515, -484520, 43526, -1545], [106538488, 1923897, 81269, -33545, 289260, 191313, -109154, 32289], [3285712, 1526579, -35221, 57413, -91903, 1339630, 302101, -31269], [228381766, 5532325, 21487, 393071, -142807, -486639, 225891, -165719], [36899015, -582953, -161949, 92171, 340974, -470169, -282643, 65706], [-987015, -8783113, 147287, -157587, 431312, 443091, 248176, 143554], [111617498, 3250967, 19807, -173901, -421844, 513290, 74764, 116520], [-2562739, 658754, 237949, 149889, -323402, 778506, -167250, 168691], [31152442, 4226491, -209299, -58385, 202314, -456737, 195871, 144915], [-111055681, 1306381, 119964, 351942, -236303, 266872, -220092, -161576], [-232771, 11908437, -144011, 354096, 286982, 981414, -118394, -8492], [15131386, -57267, 90139, 139735, 190645, 501826, 627350, -58635], [21830636, 5614038, 209220, 113708, -192130, -1257346, -314302, -86302], [-140844190, 6372135, 66249, -337771, -299198, 380008, -176772, -59376], [5484279, -6329747, -13561, 56883, -9329, -825216, -303255, 135652], [130030233, 1991173, 277781, 79836, -461646, -1096750, -447758, 54248], [195647966, -7264983, 28212, -6369, 37506, 707861, -3701, 51197], [-129062822, -23269, -106165, 149167, -435503, 475704, -244284, -61915], [87309233, 4976562, 240446, -156283, 96471, 231929, -43343, 125767], [-51352437, 6870726, -370116, 367098, 273678, -304646, 47789, -173228], [-33699126, -912186, -420491, -248423, 88039, -556291, 96520, -22952], [-130570276, 1824970, -570653, 196275, -613265, -1332319, -150660, -105065], [-109901883, 16828092, -323841, 201009, 503441, 296885, 158668, -39533], [-7369204, 14750519, 164508, -210114, 592647, -130743, 141335, 19639], [-1079394, 975984, -261250, -318770, 446242, -774742, -1432, 69846], [-107894045, 13344301, -3802, -190142, -264598, 15698, 398760, -201594], [-21636032, 2775976, 93098, -60748, -768030, 1088132, 147320, 161022], [4054797, -1503252, 219615, -294429, 631665, -517476, 288708, -34095], [78566594, -2753011, -264216, -30082, -230793, -239825, -459898, 36573], [-130022481, 5793423, 46591, 277777, -184896, 1522629, 338295, 27856], [-6266598, 6909127, 42532, 424240, 16531, 649754, 514706, -280473], [16679615, 18379374, -8947, -99973, -527861, 1163863, 9143, -240467], [56769285, 3567946, 35385, -179649, -273735, -210492, -69446, -138373], [-274763785, 4239382, 51973, 7011, -854697, 799129, 190666, -137119], [160494743, 6436376, 19453, -449071, 212054, 1773249, -20453, -125361], [-310575918, -1025572, 255097, -47375, -35490, 151115, 324510, 30340], [10745136, -5380808, -123234, 699402, -467074, -916108, 337796, -23682], [26133766, -14122473, 41851, 265675, -769058, 1682895, -145503, 82079], [-208196924, 2080232, -113299, 48611, -215687, 799857, -508999, -146564], [61502725, -5889201, -178536, -117338, -71485, 1316185, 370021, -140020], [-35426893, 254863, -191433, 8793, -32358, 360226, -478155, -97722], [141023714, 870712, -272265, 271322, -737606, 1046846, 155520, 111468], [-50158447, 191257, 105171, 535518, 367678, -715202, 703797, 228184], [111321111, 3434790, 146335, -658055, -128879, 2301979, 388046, 59667], [-100168834, 4009252, -242637, 481563, -7739, -1360298, -287205, 18907], [-2014028, -8505798, -104126, 145918, 227180, 851616, -272556, -241530], [-162709229, 12688019, 178135, -108229, -473871, 1450234, -56781, 203417], [-25921665, 9669772, 316513, -73557, -781855, -668771, -682706, 58435], [-112405574, 14798595, 448215, 346489, 17643, 392029, 433891, -145317], [-20726528, -5342484, 241697, 338279, 97701, 1263309, 58203, -132538], [70113284, 11256604, -324180, -192205, 180007, -1777357, 176388, -157074], [-350264744, 4649045, -185164, -37078, -215234, 862951, 475627, -62743], [135912244, 15378021, -65802, 46862, -687395, 695192, 490709, -30845], [2742427, 888618, 294367, 168619, 116579, -1750183, -1154, -194851], [4606953, 6089165, -43293, -156479, 963919, -1253587, -279562, 242376], [-307885038, 5982665, 181898, -53727, -329636, 1655381, -304693, 179045], [54560463, 1837517, 167705, -104324, 667758, -951470, -332488, -22222], [-105836203, 582355, -192794, -80824, -293124, 196579, 1036244, 69237], [157091711, -9389512, 244216, -188430, 5546, -764043, -586359, 249227], [-58089152, 14000658, 304754, -249944, -775342, -2037218, -485739, 152391], [-114772877, -6025902, -51623, -467084, 811598, -1018621, -651425, 186095], [-7245029, -3052509, -310085, -294733, 641442, -1034896, 317661, -75670], [-62200619, -4361680, -256574, -514018, 70316, -378030, -194963, 132357], [-101101938, -1310375, -361782, -159864, 712330, -2712481, -10201, 180371], [-250807584, -714270, -19419, -91451, -840377, -28557, -184705, -9954], [250652307, -6856660, -315673, -299853, 564431, 607629, 301606, 163171], [-151501460, -1101039, -88518, -338698, 266547, -728639, -286782, -147211], [-216963912, 2526824, 39279, -4038, 657008, 164071, -441656, 42076], [190488813, -8614075, -203543, 346797, -562779, -769399, -235778, -124108], [-213336167, 16916887, -505722, 131630, 87519, 885337, 530098, -270335], [-290513112, -13372310, 26017, 342031, -151245, -553107, -67937, -26070], [94934756, -2847077, 476479, -159655, -506462, -550925, -613579, 89629], [101575701, -10487151, -261894, 508836, -531885, 634125, -91158, -54294], [-157066896, 792503, 273078, 29032, -84608, 1803722, 18683, 36309], [130119695, 11926432, -210815, 506039, -466753, 1990321, 233939, -44806], [-25065330, 17173057, 123606, 19026, 997287, -172500, 504715, -67531], [53842202, 16542347, -150640, 90092, 229065, -2240334, 519980, 71103], [-312940376, 5676454, -160282, -243079, 827035, -1523754, -386927, -9730], [120421580, 870380, 19213, 402020, 631674, -465814, 344699, 232938], [388420261, 12961916, -156672, -39236, 256464, 1876879, 92649, -84932], [-282498741, -1609597, -160171, -27107, 292646, 1107027, -115725, -27003], [-162970265, 4874436, -327482, 102028, -84994, -3818656, -309425, 27497], [240650942, 2450406, -55080, 493850, -44954, 562876, 576366, -246918], [401676147, -8043507, -78956, 356274, -512539, -2343781, 31619, -357084], [91898301, 8000070, -437195, -21575, 130875, 1649825, 123148, 65181], [330906727, -7009071, -235932, -288074, -785243, 537972, -508996, -124824]]
